# Generated by Django 5.0.1 on 2024-06-07 01:01
import django.db.models.deletion
import swapper
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("baseapp_follows", "0005_rename_new_actor_follow_actor_and_more"),
        swapper.dependency("baseapp_profiles", "Profile"),
    ]

    operations = [
        migrations.AlterField(
            model_name="follow",
            name="actor",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="following",
                to=swapper.get_model_name("baseapp_profiles", "Profile"),
                verbose_name="actor",
            ),
        ),
        migrations.AlterField(
            model_name="follow",
            name="target",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="followers",
                to=swapper.get_model_name("baseapp_profiles", "Profile"),
                verbose_name="target",
            ),
        ),
    ]
