# Generated by Django 5.0.1 on 2024-06-07 00:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("baseapp_follows", "0003_migrate_profiles"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="follow",
            unique_together=set(),
        ),
        migrations.RemoveField(
            model_name="follow",
            name="actor_content_type",
        ),
        migrations.RemoveField(
            model_name="follow",
            name="actor_object_id",
        ),
        migrations.RemoveField(
            model_name="follow",
            name="target_content_type",
        ),
        migrations.RemoveField(
            model_name="follow",
            name="target_object_id",
        ),
    ]
