from django.apps import AppConfig


class FollowsConfig(AppConfig):
    default = True
    name = "baseapp_follows"
    verbose_name = "BaseApp Follows"
    default_auto_field = "django.db.models.AutoField"
