# Generated by Django 5.0.1 on 2024-06-07 01:02

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("baseapp_follows", "0006_alter_follow_actor_alter_follow_target"),
        migrations.swappable_dependency(settings.BASEAPP_PROFILES_PROFILE_MODEL),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="follow",
            unique_together={("actor", "target")},
        ),
    ]
